/*
 *  ircd-ratbox: an advanced Internet Relay Chat Daemon(ircd).
 *  m_idle.c: Allows opers to forge IDLE times.
 *
 *  Copyright (C) 1990 Jarkko Oikarinen and University of Oulu, Co Center
 *  Copyright (C) 1996-2002 Hybrid Development Team
 *  Copyright (C) 2002 ircd-ratbox development team
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: m_idle.c,v 1.2 2004/06/28 02:45:44 jailbird Exp $
 */

#include "stdinc.h"
#include "handlers.h"
#include "client.h"
#include "ircd.h"
#include "numeric.h"
#include "s_conf.h"
#include "s_serv.h"
#include "send.h"
#include "msg.h"
#include "parse.h"
#include "modules.h"
#include <stdlib.h>

static void mo_idle(struct Client *, struct Client *, int, char **);

struct Message idle_msgtab = {
	"IDLE", 0, 0, 0, 0, MFLG_SLOW | MFLG_UNREG, 0,
	{m_unregistered, m_ignore, m_ignore, m_ignore, mo_idle}
};
#ifndef STATIC_MODULES
void
_modinit(void)
{
	mod_add_cmd(&idle_msgtab);
}

void
_moddeinit(void)
{
	mod_del_cmd(&idle_msgtab);
}

const char *_version = "$Revision: 1.2 $";
#endif
/*
 * mo_idle - IDLE command handler
 *      parv[0] = sender prefix   
 *      parv[1] = servername   
 */
static void
mo_idle(struct Client *client_p, struct Client *source_p, int parc, char *parv[])
{
	time_t last=0;

	if (!MyClient(source_p))
		return;

	if (parc < 2) {
		sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
			   me.name, parv[0], "IDLE");
		return;
	}

	last = atol(parv[1]);
	if ((last>0) && ((CurrentTime - last) < source_p->user->last))
		source_p->user->last = CurrentTime - last;
}
